@@ -389,22 +389,37 @@ class GitConfiguration(SetupTask):
     }
 
     def is_complete(self):
-        return self.settings.get("skip_git_config")
+        if self.settings.get("skip_git_config"):
+            confirm("Skipping git configuration because 'skip_git_config' is set in MWC settings")
+            return True
+        for key, value in self.get_expected_git_config().items():
+            if self.read_git_config(key) != value:
+                return False
+        return True
 
     def run_task(self):
         (Path.home() / ".gitconfig").touch()
-        git_settings = {
-            "init.defaultBranch": "main",
-        }
-        if self.settings.get('editor') in self.editorcmds:
-            git_settings["core.editor"] = self.editorcmds[self.settings.get('editor')]
-        if self.settings.get('git_name'):
-            git_settings["user.name"] = self.settings['git_name']
-        if self.settings.get('github_email'):
-            git_settings["user.email"] = self.settings['github_email']
         for key, val in git_settings.items():
             run(f'git config --global --replace-all {key} {val}', shell=True, check=True)
 
+    def read_git_config(self, setting):
+        "Reads current git config setting"
+        result = run(f"git config --get {setting}", shell=True, check=True, 
+                capture_output=True, text=True
+        return result.stdout.strip())
+
+    def get_expected_git_config(self):
+        """Returns a dict containing expected git configuration settings.
+        """
+        git_config = {"init.defaultBranch": "main"}
+        if self.settings.get('editor') in self.editorcmds:
+            git_config["core.editor"] = self.editorcmds[self.settings.get('editor')]
+        if self.settings.get('git_name'):
+            git_config["user.name"] = self.settings['git_name']
+        if self.settings.get('github_email'):
+            git_config["user.email"] = self.settings['github_email']
+        return git_config
+
 
 
 
